// #define DEBUG

#define BAUD_RATE 115200

#include "common.h"

#include <freertos/task_snapshot.h>
#include "fpga.h"
#include "wifi.h"
#include "storage.h"

void setup() {
    printf("[START] MAX80 firmware compiled on " __DATE__ " " __TIME__ "\n");
    InitStorage();
    SetupWiFi();
    //fpga_services_start();
    printf("[RDY]\n");
}

static inline char task_state(eTaskState state)
{
    switch (state) {
    case eInvalid:
	return 'X';
    case eReady:
    case eRunning:
	return 'R';
    case eBlocked:
	return 'D';
    case eSuspended:
	return 'S';
    case eDeleted:
	return 'Z';
    default:
	return '?';
    }
}

static void dump_tasks(void)
{
    TaskHandle_t task = NULL;

    while (1) {
	task = pxTaskGetNext(task);
	if (!task)
	    break;

	printf("%-16s %c %2u\n",
	       pcTaskGetName(task),
	       task_state(eTaskGetState(task)),
	       uxTaskPriorityGet(task));
    }
}

void loop() {
    printf("loop task: %s\n", pcTaskGetName(xTaskGetCurrentTaskHandle()));
    printf("idle task: %s\n", pcTaskGetName(xTaskGetIdleTaskHandle()));

    dump_tasks();

    putchar('\n');

    vTaskDelay(120 * configTICK_RATE_HZ);
}
